Feedforward Closedloop Learning: feedforward_closedloop_learning.LayerThread Class Reference

Feedforward Closedloop Learning

Public Member Functions | Properties | List of all members
feedforward_closedloop_learning.LayerThread Class Reference
Inheritance diagram for feedforward_closedloop_learning.LayerThread:
[legend]
Collaboration diagram for feedforward_closedloop_learning.LayerThread:
[legend]

## Public Member Functions
def | __init__ (self, *args, **kwargs)
"void" | addNeuron (self, "Neuron" neuron)
"void" | start (self)
"void" | join (self)
"void" | run (self)

## Properties
| thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

## Detailed Description

    Proxy of C++ LayerThread class.

## Member Function Documentation

## ◆ addNeuron()

"void" feedforward_closedloop_learning.LayerThread.addNeuron | ( |  | self,
|  | "Neuron" | neuron
| ) |  |

    addNeuron(LayerThread self, Neuron neuron)

    Parameters
    ----------
    neuron: Neuron *

## ◆ join()

"void" feedforward_closedloop_learning.LayerThread.join | ( |  | self | ) |

    join(LayerThread self)

## ◆ run()

"void" feedforward_closedloop_learning.LayerThread.run | ( |  | self | ) |

    run(LayerThread self)

## ◆ start()

"void" feedforward_closedloop_learning.LayerThread.start | ( |  | self | ) |

    start(LayerThread self)

The documentation for this class was generated from the following file:

- feedforward_closedloop_learning.py